@@ -121,7 +121,6 @@ def log_image_dataset(
     *,
     imgs_colname: Optional[str] = None,
     imgs_location_colname: Optional[str] = None,
-    imgs_dir: Optional[str] = None,
     batch_size: int = ITER_CHUNK_SIZE,
     id: str = "id",
     label: Union[str, int] = "label",
@@ -142,7 +141,6 @@ def log_image_dataset(
         dataset=dataset,
         imgs_colname=imgs_colname,
         imgs_location_colname=imgs_location_colname,
-        imgs_dir=imgs_dir,
         batch_size=batch_size,
         id=id,
         label=label,
@@ -300,8 +298,8 @@ def log_dataset(
 
     :param dataset: The iterable or dataframe to log
     :batch_size: The number of data samples to log at a time. Useful when logging a
-    memory mapped dataset. A larger batch_size will result in faster logging at the
-    expense of more memory usage. Default 100,000
+        memory mapped dataset. A larger batch_size will result in faster logging at the
+        expense of more memory usage. Default 100,000
     :param text: str | int The column, key, or int index for text data. Default "text"
     :param id: str | int The column, key, or int index for id data. Default "id"
     :param split: Optional[str] the split for this data. Can also be set via
@@ -370,12 +368,12 @@ def log_model_outputs(
 
     model_logger = get_model_logger(
         task_type=None,
-        embs=embs,
+        embs=embs.astype(np.float32) if isinstance(embs, np.ndarray) else embs,
         ids=ids,
         split=Split[split].value if split else "",
         epoch=epoch,
-        logits=logits,
-        probs=probs,
+        logits=logits.astype(np.float32) if isinstance(logits, np.ndarray) else logits,
+        probs=probs.astype(np.float32) if isinstance(probs, np.ndarray) else probs,
         inference_name=inference_name,
     )
     model_logger.log()
