@@ -18,6 +18,7 @@ from transformers import (
 )
 
 from dataquality.schemas.split import Split
+from dataquality.utils.helpers import mps_available
 
 EVAL_METRIC = "f1"
 
@@ -69,15 +70,15 @@ def get_trainer(
         "finetuned",
         evaluation_strategy=eval_strat,
         save_strategy=IntervalStrategy.EPOCH,
-        learning_rate=3e-4,
         per_device_train_batch_size=batch_size,
         per_device_eval_batch_size=batch_size,
-        num_train_epochs=10,
+        num_train_epochs=15,
         weight_decay=0.01,
         load_best_model_at_end=load_best_model,
         push_to_hub=False,
         report_to=["all"],
         seed=42,
+        use_mps_device=mps_available(),
     )
 
     # We pass huggingface datasets here but typing expects torch datasets, so we ignore
